﻿using System;
using System.Windows.Controls;
using System.Windows;

using Infragistics;
using Infragistics.Controls.Charts;

namespace HalfCircleGrid.Controls
{
    public partial class SemiCircularGauge : UserControl
    {
        public SemiCircularGauge()
        {
            InitializeComponent();
        }

        #region Gauge Event Handlers

        /// <summary>
        /// Handles radial gauge value changed event to constrain needle movement
        /// to the radial scale bounds
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        private void RadialGaugeNeedle_ValueChanged( object sender, ValueChangedEventArgs e )
        {
            RadialGaugeNeedle needle = (RadialGaugeNeedle)sender;
            RadialGaugeScale scale = this.XamRadialGauge.Scales[0];

            if ( needle.Value < scale.StartValue || needle.Value > scale.EndValue )
            {
                //Get the normalized angle of the needle
                double needleAngle = GeometryUtil.SimplifyAngle( scale.Map( needle.Value ) );
                //Get the normalized StartAngle of the scale
                double startAngle = GeometryUtil.SimplifyAngle( scale.StartAngle );
                //Get the normalized EndAngle of the scale
                double endAngle = GeometryUtil.SimplifyAngle( scale.EndAngle );
                //Check to see if the needle is closer to the end value or the start value on the scale
                bool isCloserToStart = Math.Abs( needleAngle - startAngle ) < Math.Abs( needleAngle - endAngle );

                needle.Value = ( isCloserToStart ) ? scale.StartValue : scale.EndValue;
            }
        }


        #endregion
    }
}
